#!/usr/bin/env python3.12

import importlib
import logging
import asyncio

from typing import Any
from fastapi import FastAPI
from fastapi.middleware.cors import CORSMiddleware


logger = logging.getLogger()
logger.setLevel(logging.INFO)

loop = asyncio.get_event_loop()
app = FastAPI(title="codey.lol API",
              version="0.1a",
              contact={
                  'name': 'codey'
              },
              loop=loop)

app.loop = loop




constants = importlib.import_module("constants").Constants()
util = importlib.import_module("util").Utilities(app, constants)
glob_state = importlib.import_module("state").State(app, util, constants)


origins = [
    "https://codey.lol",
    "https://api.codey.lol"
]

app.add_middleware(CORSMiddleware,
allow_origins=origins,
allow_credentials=True,
allow_methods=["POST"],
allow_headers=["*"])



# pylint: disable=missing-function-docstring

"""
Blacklisted routes
"""

@app.get("/")
def disallow_get():
    return util.get_blocked_response()

@app.get("/{any:path}")
def disallow_get_any(var: Any = None): # pylint: disable=unused-argument
    return util.get_blocked_response()

@app.post("/")
def disallow_base_post():
    return util.get_blocked_response()

"""
End Blacklisted Routes
"""

# pylint: enable=missing-function-docstring


"""
Actionable Routes
"""
counter_endpoints = importlib.import_module("endpoints.counters").Counters(app, util, constants, glob_state)
randmsg_endpoint = importlib.import_module("endpoints.rand_msg").RandMsg(app, util, constants, glob_state)
transcription_endpoints = importlib.import_module("endpoints.transcriptions").Transcriptions(app, util, constants, glob_state)
ai_endpoints = importlib.import_module("endpoints.ai").AI(app, util, constants, glob_state)
# Below also provides: /lyric_cache_list/ (in addition to /lyric_search/)
lyric_search_endpoint = importlib.import_module("endpoints.lyric_search").LyricSearch(app, util, constants, glob_state)
# Below provides numerous LastFM-fed endpoints
lastfm_endpoints = importlib.import_module("endpoints.lastfm").LastFM(app, util, constants, glob_state)
# Below: YT endpoint(s)
yt_endpoints = importlib.import_module("endpoints.yt").YT(app, util, constants, glob_state)
# Below: XC endpoint(s)
xc_endpoints = importlib.import_module("endpoints.xc").XC(app, util, constants, glob_state)

# Below: Karma endpoint(s)
karma_endpoints = importlib.import_module("endpoints.karma").Karma(app, util, constants, glob_state)

# @app.on_event("startup")
# @repeat_every(seconds=10)
# async def cah_tasks() -> None:
#     return await cah_endpoints.periodicals()



"""
End Actionable Routes
"""